==> ejc-idm-client-3.0.0-20200817.124235-5-sources.jar: com/ejianc/framework/idmclient/cas/logout/SingleSignOutFilter.java <==
package com.ejianc.framework.idmclient.cas.logout;

import java.io.IOException;
import java.util.concurrent.atomic.AtomicBoolean;

import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jasig.cas.client.session.SessionMappingStorage;
import org.jasig.cas.client.util.AbstractConfigurationFilter;
import org.springframework.context.ApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;

import com.ejianc.framework.idmclient.IdmFilterConfiguration;

public final class SingleSignOutFilter extends AbstractConfigurationFilter {
	private static final SingleSignOutHandler HANDLER = new SingleSignOutHandler();
	private AtomicBoolean handlerInitialized = new AtomicBoolean(false);

	public void init(FilterConfig filterConfig) throws ServletException {
		ServletContext context = filterConfig.getServletContext();  
		ApplicationContext ctx = WebApplicationContextUtils.getWebApplicationContext(context);
		
		if (!this.isIgnoreInitConfiguration()) {
			HANDLER.setArtifactParameterName(this.getPropertyFromInitParams(filterConfig, "artifactParameterName", "ticket"));
			HANDLER.setLogoutParameterName(this.getPropertyFromInitParams(filterConfig, "logoutParameterName", "logoutRequest"));
			HANDLER.setFrontLogoutParameterName(this.getPropertyFromInitParams(filterConfig, "frontLogoutParameterName", "SAMLRequest"));
			HANDLER.setRelayStateParameterName(this.getPropertyFromInitParams(filterConfig, "relayStateParameterName", "RelayState"));
			IdmFilterConfiguration idmFilterConfiguration = ctx.getBean("idmFilterConfiguration",IdmFilterConfiguration.class);
			String casUrl = idmFilterConfiguration.getCasUrl();
			if (StringUtils.isNotBlank(casUrl)) {
				HANDLER.setCasServerUrlPrefix(casUrl);
			} else {
				HANDLER.setCasServerUrlPrefix(this.getPropertyFromInitParams(filterConfig, "casServerUrlPrefix", (String) null));
			}

			HANDLER.setArtifactParameterOverPost(this.parseBoolean(this.getPropertyFromInitParams(filterConfig, "artifactParameterOverPost", "false")));
		}

		HANDLER.init();
		this.handlerInitialized.set(true);
	}

	public void setArtifactParameterName(String name) {
		HANDLER.setArtifactParameterName(name);
	}

	public void setLogoutParameterName(String name) {
		HANDLER.setLogoutParameterName(name);
	}

	public void setFrontLogoutParameterName(String name) {
		HANDLER.setFrontLogoutParameterName(name);
	}

	public void setRelayStateParameterName(String name) {
		HANDLER.setRelayStateParameterName(name);
	}

	public void setCasServerUrlPrefix(String casServerUrlPrefix) {
		HANDLER.setCasServerUrlPrefix(casServerUrlPrefix);
	}

	public void setSessionMappingStorage(SessionMappingStorage storage) {
		HANDLER.setSessionMappingStorage(storage);
	}

	public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
		HttpServletRequest request = (HttpServletRequest) servletRequest;
		HttpServletResponse response = (HttpServletResponse) servletResponse;
		if (!this.handlerInitialized.getAndSet(true)) {
			HANDLER.init();
		}

		if (HANDLER.process(request, response)) {
			filterChain.doFilter(servletRequest, servletResponse);
		}

	}

	public void destroy() {}

	protected static SingleSignOutHandler getSingleSignOutHandler() {
		return HANDLER;
	}
}

==> ejc-idm-client-3.0.0-20250930.052538-31-sources.jar: com/ejianc/framework/idmclient/cas/logout/SingleSignOutFilter.java <==
package com.ejianc.framework.idmclient.cas.logout;

import java.io.IOException;
import java.util.concurrent.atomic.AtomicBoolean;

import javax.servlet.FilterChain;
import javax.servlet.FilterConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.ServletRequest;
import javax.servlet.ServletResponse;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import org.apache.commons.lang.StringUtils;
import org.jasig.cas.client.session.SessionMappingStorage;
import org.jasig.cas.client.util.AbstractConfigurationFilter;
import org.springframework.context.ApplicationContext;
import org.springframework.web.context.support.WebApplicationContextUtils;

import com.ejianc.framework.core.util.Utils;
import com.ejianc.framework.idmclient.IdmFilterConfiguration;

public final class SingleSignOutFilter extends AbstractConfigurationFilter {
	private static final SingleSignOutHandler HANDLER = new SingleSignOutHandler();
	private AtomicBoolean handlerInitialized = new AtomicBoolean(false);
	IdmFilterConfiguration idmFilterConfiguration = null;

	public void init(FilterConfig filterConfig) throws ServletException {
		ServletContext context = filterConfig.getServletContext();  
		ApplicationContext ctx = WebApplicationContextUtils.getWebApplicationContext(context);
		
		if (!this.isIgnoreInitConfiguration()) {
			HANDLER.setArtifactParameterName(this.getPropertyFromInitParams(filterConfig, "artifactParameterName", "ticket"));
			HANDLER.setLogoutParameterName(this.getPropertyFromInitParams(filterConfig, "logoutParameterName", "logoutRequest"));
			HANDLER.setFrontLogoutParameterName(this.getPropertyFromInitParams(filterConfig, "frontLogoutParameterName", "SAMLRequest"));
			HANDLER.setRelayStateParameterName(this.getPropertyFromInitParams(filterConfig, "relayStateParameterName", "RelayState"));
			idmFilterConfiguration = ctx.getBean("idmFilterConfiguration",IdmFilterConfiguration.class);
			String casUrl = idmFilterConfiguration.getCasUrl();
			if (StringUtils.isNotBlank(casUrl)) {
				HANDLER.setCasServerUrlPrefix(casUrl);
			} else {
				HANDLER.setCasServerUrlPrefix(this.getPropertyFromInitParams(filterConfig, "casServerUrlPrefix", (String) null));
			}

			HANDLER.setArtifactParameterOverPost(this.parseBoolean(this.getPropertyFromInitParams(filterConfig, "artifactParameterOverPost", "false")));
		}

		HANDLER.init();
		this.handlerInitialized.set(true);
	}

	public void setArtifactParameterName(String name) {
		HANDLER.setArtifactParameterName(name);
	}

	public void setLogoutParameterName(String name) {
		HANDLER.setLogoutParameterName(name);
	}

	public void setFrontLogoutParameterName(String name) {
		HANDLER.setFrontLogoutParameterName(name);
	}

	public void setRelayStateParameterName(String name) {
		HANDLER.setRelayStateParameterName(name);
	}

	public void setCasServerUrlPrefix(String casServerUrlPrefix) {
		HANDLER.setCasServerUrlPrefix(casServerUrlPrefix);
	}

	public void setSessionMappingStorage(SessionMappingStorage storage) {
		HANDLER.setSessionMappingStorage(storage);
	}

	public void doFilter(ServletRequest servletRequest, ServletResponse servletResponse, FilterChain filterChain) throws IOException, ServletException {
		HttpServletRequest request = (HttpServletRequest) servletRequest;
		HttpServletResponse response = (HttpServletResponse) servletResponse;
		if (!this.handlerInitialized.getAndSet(true)) {
			HANDLER.init();
		}
		String serverName = request.getServerName();
		String casUrl = idmFilterConfiguration.getCasUrl();
		if(Utils.getDingDingDomain().contains(serverName)) {
			String casServerName = Utils.getDingDingDomain();
			HANDLER.setCasServerUrlPrefix(casServerName+"/sso");
		}else{
			if("localhost".equals(serverName) || "127.0.0.1".equals(serverName) 
					|| idmFilterConfiguration.getServerName().contains(serverName)
					|| "false".equals(idmFilterConfiguration.getMultiDomain())) {
				HANDLER.setCasServerUrlPrefix(casUrl);
			}else{
				if(idmFilterConfiguration.getCasUrl().startsWith("https")) {
					HANDLER.setCasServerUrlPrefix("https://" + request.getServerName() + "/sso");
				}else{
					HANDLER.setCasServerUrlPrefix("http://" + request.getServerName() + "/sso");
				}
			}
		}
		
		if (HANDLER.process(request, response)) {
			filterChain.doFilter(servletRequest, servletResponse);
		}

	}

	public void destroy() {}

	protected static SingleSignOutHandler getSingleSignOutHandler() {
		return HANDLER;
	}
}
